# mergeplg

[![Actions Status][actions-badge]][actions-link]
[![Documentation Status][rtd-badge]][rtd-link]

[![PyPI version][pypi-version]][pypi-link]
[![Conda-Forge][conda-badge]][conda-link]
[![PyPI platforms][pypi-platforms]][pypi-link]

<!-- SPHINX-START -->

`mergeplg` is a collection of methods to merge rainfall sensor data from point,
line and grid geometries. Typically the sensors are rain gauges (point), CML or
SML (line) and weather radar or satellites (grid).

This package is currently in a very early stage of development.

<!-- prettier-ignore-start -->
[actions-badge]:            https://github.com/OpenSenseAction/mergeplg/workflows/CI/badge.svg
[actions-link]:             https://github.com/OpenSenseAction/mergeplg/actions
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/mergeplg
[conda-link]:               https://github.com/conda-forge/mergeplg-feedstock
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/OpenSenseAction/mergeplg/discussions
[pypi-link]:                https://pypi.org/project/mergeplg/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/mergeplg
[pypi-version]:             https://img.shields.io/pypi/v/mergeplg
[rtd-badge]:                https://readthedocs.org/projects/mergeplg/badge/?version=latest
[rtd-link]:                 https://mergeplg.readthedocs.io/en/latest/?badge=latest

<!-- prettier-ignore-end -->
